package com.zehong.system.mapper;

import java.util.List;
import java.util.Map;

import com.zehong.system.domain.TDeviceInfo;

/**
 * 设备信息Mapper接口
 * 
 * @author zehong
 * @date 2021-07-09
 */
public interface TDeviceInfoMapper 
{
    /**
     * 查询设备信息
     * 
     * @param deviceId 设备信息ID
     * @return 设备信息
     */
    public TDeviceInfo selectTDeviceInfoById(int deviceId);

    /**
     * 查询设备信息
     *
     * @param pipeId 管道ID
     * @return 设备信息
     */
    public List<TDeviceInfo> selectTDeviceInfoByPipeId(int pipeId);

    /**
     * 查询设备信息列表
     * 
     * @param tDeviceInfo 设备信息
     * @return 设备信息集合
     */
    public List<TDeviceInfo> selectTDeviceInfoList(TDeviceInfo tDeviceInfo);

    /**
     * 统计各设备类型的设备总数
     * @return
     */
    public List<Map<Object, Object>> countDeviceByType();

    /**
     * 新增设备信息
     * 
     * @param tDeviceInfo 设备信息
     * @return 结果
     */
    public int insertTDeviceInfo(TDeviceInfo tDeviceInfo);

    /**
     * 修改设备信息
     * 
     * @param tDeviceInfo 设备信息
     * @return 结果
     */
    public int updateTDeviceInfo(TDeviceInfo tDeviceInfo);

    /**
     * 删除设备信息
     * 
     * @param deviceId 设备信息ID
     * @return 结果
     */
    public int deleteTDeviceInfoById(int deviceId);

    /**
     * 批量删除设备信息
     * 
     * @param deviceIds 需要删除的数据ID
     * @return 结果
     */
    public int deleteTDeviceInfoByIds(int[] deviceIds);
}
